@@ -1,8 +1,10 @@
-VERSION = '1.4.0'
+VERSION = "2.3.0"
 
 from django.utils.functional import SimpleLazyObject
 from django.utils.module_loading import import_string
+
 from .blueprint import Blueprint
 from .lazy import Lazy
+from .utils import get_model as M
 
-factory = SimpleLazyObject(lambda: import_string('django_fakery.faker_factory.factory'))
+factory = SimpleLazyObject(lambda: import_string("django_fakery.faker_factory.factory"))
